

.. _external_uml:

=========================
ExternalDependentVariable
=========================

-----------------
Generalized Class
-----------------

.. raw:: html

    <a class="btn btn-default" href=./dependent_variable.html#_dependent-var-uml>
    DependentVariable </a>


Description
***********

An ExternalDependentVariable is where the components of the dependent variable
are defined in an external file whose location is defined as the value of the
``components_url`` key.


Attributes
**********

.. cssclass:: table-bordered table-hover table-striped

===============  =======================    =====================
Name             Type                       Description
===============  =======================    =====================
components_url   String                     The location where the components
                                            of the dependent variable are
                                            stored as a binary data.
===============  =======================    =====================
